@@ -60,8 +60,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     GtkWidget      *label1;
     GtkWidget      *wTF_Device;
     GtkWidget      *eventbox1;
-    GtkWidget      *alignment1;
-    GtkObject      *wSc_Period_adj;
+    GtkAdjustment  *wSc_Period_adj;
     GtkWidget      *wSc_Period;
     GtkWidget      *label2;
     GtkWidget      *wTB_Title;
@@ -91,23 +90,21 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     GtkWidget      *wPB_Rcolor;
     GtkWidget      *wPB_Wcolor;
 
-    table1 = gtk_table_new (3, 2, FALSE);
+    table1 = gtk_grid_new ();
+    gtk_grid_set_column_spacing(GTK_GRID (table1), 2);
+    gtk_grid_set_row_spacing(GTK_GRID (table1), 2);
     gtk_widget_show (table1);
     gtk_box_pack_start (GTK_BOX (vbox1), table1, FALSE, FALSE, 0);
 
     label1 = gtk_label_new (_("Device"));
     gtk_widget_show (label1);
-    gtk_table_attach (GTK_TABLE (table1), label1, 0, 1, 0, 1,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), label1, 0, 0, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label1), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label1), 0, 0.5);
+    gtk_widget_set_valign(GTK_WIDGET (label1), GTK_ALIGN_CENTER);
 
     wTF_Device = gtk_entry_new ();
     gtk_widget_show (wTF_Device);
-    gtk_table_attach (GTK_TABLE (table1), wTF_Device, 1, 2, 0, 1,
-		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), wTF_Device, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (wTF_Device,
 			  _("Input the device name, then press <Enter>"));
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Device), 64);
@@ -115,52 +112,44 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
 
     eventbox1 = gtk_event_box_new ();
     gtk_widget_show (eventbox1);
-    gtk_table_attach (GTK_TABLE (table1), eventbox1, 1, 2, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
-
-    alignment1 = gtk_alignment_new (0.5, 0.5, 1, 1);
-    gtk_widget_show (alignment1);
-    gtk_container_add (GTK_CONTAINER (eventbox1), alignment1);
+    gtk_grid_attach (GTK_GRID (table1), eventbox1, 1, 2, 1, 1);
+    gtk_widget_set_valign(GTK_WIDGET(eventbox1), GTK_ALIGN_CENTER);
+    gtk_widget_set_halign(GTK_WIDGET(eventbox1), GTK_ALIGN_CENTER);
+    gtk_widget_set_vexpand(GTK_WIDGET(eventbox1), TRUE);
+    gtk_widget_set_hexpand(GTK_WIDGET(eventbox1), TRUE);
 
     wSc_Period_adj = gtk_adjustment_new (0.5, 0.25, 4, 0.05, 1, 0);
     wSc_Period =
 	gtk_spin_button_new (GTK_ADJUSTMENT (wSc_Period_adj), 1, 3);
     gtk_widget_show (wSc_Period);
-    gtk_container_add (GTK_CONTAINER (alignment1), wSc_Period);
+    gtk_container_add (GTK_CONTAINER (eventbox1), wSc_Period);
     gtk_widget_set_tooltip_text (wSc_Period, _("Data collection period"));
     gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (wSc_Period), TRUE);
 
     label2 = gtk_label_new (_("Update interval (s) "));
     gtk_widget_show (label2);
-    gtk_table_attach (GTK_TABLE (table1), label2, 0, 1, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), label2, 0, 2, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label2), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label2), 0, 0.5);
+    gtk_widget_set_valign(GTK_WIDGET (label2), GTK_ALIGN_CENTER);
 
     wTB_Title = gtk_check_button_new_with_mnemonic (_("Label"));
     gtk_widget_show (wTB_Title);
-    gtk_table_attach (GTK_TABLE (table1), wTB_Title, 0, 1, 1, 2,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), wTB_Title, 0, 1, 1, 1);
     gtk_widget_set_tooltip_text (wTB_Title, _("Tick to display label"));
 
     wTF_Title = gtk_entry_new ();
     gtk_widget_show (wTF_Title);
-    gtk_table_attach (GTK_TABLE (table1), wTF_Title, 1, 2, 1, 2,
-		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (table1), wTF_Title, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (wTF_Title,
 			  _("Input the label, then press <Enter>"));
     gtk_entry_set_max_length (GTK_ENTRY (wTF_Title), 16);
     gtk_entry_set_text (GTK_ENTRY (wTF_Title), _("hda1"));
 
-    hseparator7 = gtk_hseparator_new ();
+    hseparator7 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator7);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator7, TRUE, TRUE, 0);
 
-    hbox2 = gtk_hbox_new (FALSE, 8);
+    hbox2 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
     gtk_widget_show (hbox2);
     gtk_box_pack_start (GTK_BOX (vbox1), hbox2, TRUE, TRUE, 0);
 
@@ -187,7 +176,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     wRB_IO_group =
 	gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_BusyTime));
 
-    wHBox_MaxIO = gtk_hbox_new (FALSE, 0);
+    wHBox_MaxIO = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 0);
     gtk_widget_show (wHBox_MaxIO);
     gtk_box_pack_start (GTK_BOX (vbox1), wHBox_MaxIO, TRUE, TRUE, 0);
 
@@ -195,7 +184,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_show (label3);
     gtk_box_pack_start (GTK_BOX (wHBox_MaxIO), label3, FALSE, FALSE, 0);
     gtk_label_set_justify (GTK_LABEL (label3), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label3), 0, 0.5);
+    gtk_widget_set_valign (GTK_WIDGET (label3), GTK_ALIGN_CENTER);
 
     wTF_MaxXfer = gtk_entry_new ();
     gtk_widget_show (wTF_MaxXfer);
@@ -205,7 +194,7 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_entry_set_max_length (GTK_ENTRY (wTF_MaxXfer), 3);
     gtk_entry_set_text (GTK_ENTRY (wTF_MaxXfer), _("35"));
 
-    hseparator8 = gtk_hseparator_new ();
+    hseparator8 = gtk_separator_new (GTK_ORIENTATION_HORIZONTAL);
     gtk_widget_show (hseparator8);
     gtk_box_pack_start (GTK_BOX (vbox1), hseparator8, FALSE, FALSE, 0);
 
@@ -216,59 +205,51 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     gtk_widget_set_tooltip_text (wTB_RWcombined,
 			  _("Combine Read/Write data into one single monitor?"));
 
-    wTa_SingleBar = gtk_table_new (1, 2, FALSE);
+    wTa_SingleBar = gtk_grid_new ();
+    gtk_grid_set_column_spacing(GTK_GRID (wTa_SingleBar), 2);
+    gtk_grid_set_row_spacing(GTK_GRID (wTa_SingleBar), 2);
     gtk_widget_show (wTa_SingleBar);
     gtk_box_pack_start (GTK_BOX (vbox1), wTa_SingleBar, FALSE, FALSE, 0);
 
     label7 = gtk_label_new (_("Bar color "));
     gtk_widget_show (label7);
-    gtk_table_attach (GTK_TABLE (wTa_SingleBar), label7, 0, 1, 0, 1,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_SingleBar), label7, 0, 0, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label7), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label7), 0, 0.5);
+    gtk_widget_set_valign (GTK_WIDGET (label7), GTK_ALIGN_CENTER);
 
-    wPB_RWcolor = gtk_button_new_with_mnemonic ("");
+    wPB_RWcolor = gtk_color_button_new();
     gtk_widget_show (wPB_RWcolor);
-    gtk_widget_set_size_request (wPB_RWcolor, -1, 25);
-    gtk_table_attach (GTK_TABLE (wTa_SingleBar), wPB_RWcolor, 1, 2, 0, 1,
-		      (GtkAttachOptions) (GTK_FILL | GTK_EXPAND),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_SingleBar), wPB_RWcolor, 1, 0, 1, 1);
     gtk_widget_set_tooltip_text (wPB_RWcolor, _("Press to change color"));
+    gtk_widget_set_hexpand (GTK_WIDGET (wPB_RWcolor), TRUE);
 
-    wTa_DualBars = gtk_table_new (3, 2, FALSE);
+    wTa_DualBars = gtk_grid_new ();
+    gtk_grid_set_column_spacing(GTK_GRID (wTa_DualBars), 2);
+    gtk_grid_set_row_spacing(GTK_GRID (wTa_DualBars), 2);
     gtk_widget_show (wTa_DualBars);
     gtk_box_pack_start (GTK_BOX (vbox1), wTa_DualBars, FALSE, FALSE, 0);
 
     label5 = gtk_label_new (_("Read bar color "));
     gtk_widget_show (label5);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), label5, 0, 1, 1, 2,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), label5, 0, 1, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label5), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label5), 0, 0.5);
+    gtk_widget_set_valign (GTK_WIDGET (label5), GTK_ALIGN_CENTER);
 
     label6 = gtk_label_new (_("Write bar color "));
     gtk_widget_show (label6);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), label6, 0, 1, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), label6, 0, 2, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label6), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label6), 0, 0.5);
+    gtk_widget_set_valign (GTK_WIDGET (label6), GTK_ALIGN_CENTER);
 
     label8 = gtk_label_new (_("Bar order"));
     gtk_widget_show (label8);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), label8, 0, 1, 0, 1,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (0), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), label8, 0, 0, 1, 1);
     gtk_label_set_justify (GTK_LABEL (label8), GTK_JUSTIFY_LEFT);
-    gtk_misc_set_alignment (GTK_MISC (label8), 0, 0.5);
+    gtk_widget_set_valign (GTK_WIDGET (label8), GTK_ALIGN_CENTER);
 
-    hbox1 = gtk_hbox_new (FALSE, 8);
+    hbox1 = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 8);
     gtk_widget_show (hbox1);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), hbox1, 1, 2, 0, 1,
-		      (GtkAttachOptions) (GTK_EXPAND | GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), hbox1, 1, 0, 1, 1);
 
     wRB_ReadWriteOrder =
 	gtk_radio_button_new_with_mnemonic (NULL, _("Read-Write"));
@@ -294,21 +275,17 @@ int CreateConfigGUI (GtkWidget * vbox1, struct gui_t *p_poGUI)
     wRB_ReadWriteOrder_group =
 	gtk_radio_button_get_group (GTK_RADIO_BUTTON (wRB_WriteReadOrder));
 
-    wPB_Rcolor = gtk_button_new_with_mnemonic ("");
+    wPB_Rcolor = gtk_color_button_new();
     gtk_widget_show (wPB_Rcolor);
-    gtk_widget_set_size_request (wPB_Rcolor, -1, 25);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), wPB_Rcolor, 1, 2, 1, 2,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), wPB_Rcolor, 1, 1, 1, 1);
     gtk_widget_set_tooltip_text (wPB_Rcolor, _("Press to change color"));
+    gtk_widget_set_hexpand (GTK_WIDGET (wPB_Rcolor), TRUE);
 
-    wPB_Wcolor = gtk_button_new_with_mnemonic ("");
+    wPB_Wcolor = gtk_color_button_new();
     gtk_widget_show (wPB_Wcolor);
-    gtk_widget_set_size_request (wPB_Wcolor, -1, 25);
-    gtk_table_attach (GTK_TABLE (wTa_DualBars), wPB_Wcolor, 1, 2, 2, 3,
-		      (GtkAttachOptions) (GTK_FILL),
-		      (GtkAttachOptions) (GTK_FILL), 0, 0);
+    gtk_grid_attach (GTK_GRID (wTa_DualBars), wPB_Wcolor, 1, 2, 1, 1);
     gtk_widget_set_tooltip_text (wPB_Wcolor, _("Press to change color"));
+    gtk_widget_set_hexpand (GTK_WIDGET (wPB_Wcolor), TRUE);
 
     if (p_poGUI) {
 	COPYVAL (p_poGUI, wTF_Device);
