@@ -39,12 +39,6 @@
 #include <errno.h>
 #include <sys/stat.h>
 
-#ifdef LIBXFCE4PANEL_CHECK_VERSION
-#if LIBXFCE4PANEL_CHECK_VERSION (4,9,0)
-#define HAS_PANEL_49
-#endif
-#endif
-
 #define PLUGIN_NAME	"DiskPerf"
 #define BORDER          8
 
@@ -290,6 +284,7 @@ static gboolean SetTimer (void *p_pvPlugin)
 	/* Recurrently update the panel-docked monitor bars through a
 	   timer */
 {
+    GtkSettings *settings;
     struct diskperf_t *poPlugin = (diskperf_t *) p_pvPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
 
@@ -303,7 +298,6 @@ static gboolean SetTimer (void *p_pvPlugin)
 
     /* reduce the default tooltip timeout to be smaller than the update interval otherwise
      * we won't see tooltips on GTK 2.16 or newer */
-    GtkSettings *settings;
     settings = gtk_settings_get_default();
     if (g_object_class_find_property(G_OBJECT_GET_CLASS(settings), "gtk-tooltip-timeout"))
         g_object_set(settings, "gtk-tooltip-timeout",
@@ -320,6 +314,9 @@ static gboolean SetTimer (void *p_pvPlugin)
 static int SetSingleBarColor (struct diskperf_t *p_poPlugin, int p_iBar)
 	/* Set the color of a single monitor bar */
 {
+#if GTK_CHECK_VERSION (3, 16, 0)
+    gchar * css;
+#endif
     struct diskperf_t *poPlugin = p_poPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
@@ -327,22 +324,15 @@ static int SetSingleBarColor (struct diskperf_t *p_poPlugin, int p_iBar)
 
     pwBar = poMonitor->aoPerfBar[p_iBar].pwBar;
 #if GTK_CHECK_VERSION (3, 16, 0)
-    GtkCssProvider *css_provider;
 #if GTK_CHECK_VERSION (3, 20, 0)
-    gchar * css = g_strdup_printf("progressbar trough { min-width: 4px; min-height: 4px; } \
-                                   progressbar progress { min-width: 4px; min-height: 4px; \
-                                                          background-color: %s; background-image: none; }",
+    css = g_strdup_printf("progressbar progress { background-color: %s; background-image: none; }",
 #else
-    gchar * css = g_strdup_printf(".progressbar { background-color: %s; background-image: none; }",
+    css = g_strdup_printf(".progressbar progress { background-color: %s; background-image: none; }",
 #endif
                                   gdk_rgba_to_string(&poConf->aoColor[p_iBar]));
     /* Setup Gtk style */
-    css_provider = gtk_css_provider_new ();
-    gtk_css_provider_load_from_data (css_provider, css, strlen(css), NULL);
-    gtk_style_context_add_provider (
-        GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (*pwBar))),
-        GTK_STYLE_PROVIDER (css_provider),
-        GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+    DBG("setting css to %s for bar %d", css, p_iBar);
+    gtk_css_provider_load_from_data (g_object_get_data(G_OBJECT(*pwBar),"css_provider"), css, strlen(css), NULL);
     g_free(css);
 #else
 	gtk_widget_override_background_color(GTK_WIDGET(*pwBar),
@@ -366,6 +356,7 @@ static int SetMonitorBarColor (struct diskperf_t *p_poPlugin)
     struct diskperf_t *poPlugin = p_poPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
 
+    DBG("!");
     if (poConf->fRW_DataCombined)
 	SetSingleBarColor (p_poPlugin, RW_DATA);
     else {
@@ -383,6 +374,7 @@ static int ResetMonitorBar (struct diskperf_t *p_poPlugin)
     struct diskperf_t *poPlugin = p_poPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
+    DBG("!");
 
     poMonitor->aoPerfBar[R_DATA].pwBar =
 	poMonitor->awProgressBar + (poConf->eMonitorBarOrder == WR_ORDER);
@@ -401,11 +393,15 @@ static int CreateMonitorBars (struct diskperf_t *p_poPlugin,
 			      GtkOrientation p_iOrientation)
 	/* Create the panel progressive bars */
 {
+#if GTK_CHECK_VERSION (3, 16, 0)
+    GtkCssProvider *css_provider;
+#endif
     struct diskperf_t *poPlugin = p_poPlugin;
     struct param_t *poConf = &(poPlugin->oConf.oParam);
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
     Widget_t       *pwBar;
     int             i;
+    DBG("!");
 
     poMonitor->wBox = gtk_box_new (p_iOrientation, 0);
     gtk_widget_show (poMonitor->wBox);
@@ -426,6 +422,28 @@ static int CreateMonitorBars (struct diskperf_t *p_poPlugin,
 	gtk_progress_bar_set_inverted (GTK_PROGRESS_BAR(*pwBar),
 					   (p_iOrientation ==
 					    GTK_ORIENTATION_HORIZONTAL));
+#if GTK_CHECK_VERSION (3, 16, 0)
+	css_provider = gtk_css_provider_new ();
+#if GTK_CHECK_VERSION (3, 20, 0)
+	gtk_css_provider_load_from_data (css_provider, "\
+		progressbar.horizontal trough { min-height: 4px; }\
+		progressbar.horizontal progress { min-height: 4px; }\
+		progressbar.vertical trough { min-width: 4px; }\
+		progressbar.vertical progress { min-width: 4px; }",
+#else
+	gtk_css_provider_load_from_data (css_provider, "\
+		.progressbar.horizontal trough { min-height: 4px; }\
+		.progressbar.horizontal progress { min-height: 4px; }\
+		.progressbar.vertical trough { min-width: 4px; }\
+		.progressbar.vertical progress { min-width: 4px; }",
+#endif
+		-1, NULL);
+	gtk_style_context_add_provider (
+		GTK_STYLE_CONTEXT (gtk_widget_get_style_context (GTK_WIDGET (*pwBar))),
+		GTK_STYLE_PROVIDER (css_provider),
+		GTK_STYLE_PROVIDER_PRIORITY_APPLICATION);
+	g_object_set_data(G_OBJECT(*pwBar), "css_provider", css_provider);
+#endif
 
 	if ((i == 1) && poConf->fRW_DataCombined)
 	    gtk_widget_hide (GTK_WIDGET (*pwBar));
@@ -571,13 +589,11 @@ static void diskperf_read_config (XfcePanelPlugin *plugin,
     else
         gtk_widget_hide (GTK_WIDGET (poMonitor->wTitle));
 
-#ifdef HAS_PANEL_49
     /* unset small if we are in deskbar mode and we want the title */
     if (poConf->fTitleDisplayed && xfce_panel_plugin_get_mode(poPlugin->plugin) == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
       xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), FALSE);
     else
       xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), TRUE);
-#endif
 
     if ((value = xfce_rc_read_entry (rc, (CONF_LABEL_TEXT), NULL))) {
         memset (poConf->acTitle, 0, sizeof (poConf->acTitle));
@@ -616,7 +632,7 @@ static void diskperf_read_config (XfcePanelPlugin *plugin,
     if ((value = xfce_rc_read_entry (rc, (CONF_READ_WRITE_COLOR), NULL))) {
         gdk_rgba_parse (poConf->aoColor + RW_DATA, value);
     }
-    SetMonitorBarColor (poPlugin);
+    ResetMonitorBar (poPlugin);
 
     xfce_rc_close (rc);
 }				/* diskperf_read_config() */
@@ -703,13 +719,11 @@ static void ToggleTitle (Widget_t p_w, void *p_pvPlugin)
     else
 	gtk_widget_hide (GTK_WIDGET (poMonitor->wTitle));
 
-#ifdef HAS_PANEL_49
     /* unset small if we are in deskbar mode and we want the title */
     if (poConf->fTitleDisplayed && xfce_panel_plugin_get_mode(poPlugin->plugin) == XFCE_PANEL_PLUGIN_MODE_DESKBAR)
       xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), FALSE);
     else
       xfce_panel_plugin_set_small (XFCE_PANEL_PLUGIN (poPlugin->plugin), TRUE);
-#endif
 }				/* ToggleTitle() */
 
 	/**************************************************************/
@@ -737,7 +751,7 @@ static void ToggleStatistics (Widget_t p_w, void *p_pvPlugin)
     struct gui_t   *poGUI = &(poPlugin->oConf.oGUI);
 
     poConf->eStatistics = !(poConf->eStatistics);
-    TRACE ("ToggleStatistics(): %d\n", poConf->eStatistics);
+    DBG ("%d", poConf->eStatistics);
     switch (poConf->eStatistics) {
 	case BUSY_TIME:
 	    gtk_widget_hide (GTK_WIDGET (poGUI->wHBox_MaxIO));
@@ -771,7 +785,7 @@ static void ToggleRWintegration (Widget_t p_w, void *p_pvPlugin)
 
     poConf->fRW_DataCombined =
 	gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (p_w));
-    TRACE ("ToggleRWintegration(): %d\n", poConf->fRW_DataCombined);
+    DBG ("%d", poConf->fRW_DataCombined);
     if (poConf->fRW_DataCombined) {
 	gtk_widget_hide (GTK_WIDGET (poGUI->wTa_DualBars));
 	gtk_widget_show (GTK_WIDGET (poGUI->wTa_SingleBar));
@@ -794,8 +808,9 @@ static void ToggleRWorder (Widget_t p_w, void *p_pvPlugin)
     struct param_t *poConf = &(poPlugin->oConf.oParam);
 
     poConf->eMonitorBarOrder = !(poConf->eMonitorBarOrder);
-    TRACE ("ToggleRWorder(): %d\n", poConf->eMonitorBarOrder);
+    DBG ("%d", poConf->eMonitorBarOrder);
     ResetMonitorBar (poPlugin);
+    DisplayPerf (poPlugin);
 }				/* ToggleRWorder() */
 
 	/**************************************************************/
@@ -827,7 +842,6 @@ static void SetPeriod (Widget_t p_wSc, void *p_pvPlugin)
     float           r;
 
     timerNeedsUpdate = 1;
-    TRACE ("SetPeriod()\n");
     r = gtk_spin_button_get_value (GTK_SPIN_BUTTON (p_wSc));
     poConf->iPeriod_ms = round(r * 1000);
     DBG("Update period rounded to %dms\n", poConf->iPeriod_ms);
@@ -865,7 +879,7 @@ static void UpdateConf (diskperf_t *poPlugin)
     struct conf_t  *poConf = &(poPlugin->oConf);
     struct gui_t   *poGUI = &(poConf->oGUI);
 
-    TRACE ("UpdateConf()\n");
+    DBG ("!");
     SetDevice (poGUI->wTF_Device, poPlugin);
     SetLabel (poGUI->wTF_Title, poPlugin);
     SetXferRate (poGUI->wTF_MaxXfer, poPlugin);
@@ -959,7 +973,7 @@ static void diskperf_create_options (XfcePanelPlugin *plugin,
     Widget_t       *apwColorPB[NMONITORS];
     int             i;
 
-    TRACE ("diskperf_create_options()\n");
+    DBG ("!");
 
     (void) CheckStatsAvailability ();
 
@@ -1075,7 +1089,7 @@ static gboolean diskperf_set_size (XfcePanelPlugin *plugin, int p_size,
     Widget_t       *pwBar;
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
 
-    TRACE ("diskperf_set_size(%d)\n", p_size);
+    DBG ("%d", p_size);
     gtk_container_set_border_width (GTK_CONTAINER
 				    (poMonitor->wBox), p_size > 26 ? 2 : 1);
     if (xfce_panel_plugin_get_orientation (plugin) == 
@@ -1097,7 +1111,6 @@ static gboolean diskperf_set_size (XfcePanelPlugin *plugin, int p_size,
     return TRUE;
 }				/* diskperf_set_size() */
 
-#ifdef HAS_PANEL_49
 	/**************************************************************/
 
 static void diskperf_set_mode (XfcePanelPlugin *plugin,
@@ -1107,23 +1120,25 @@ static void diskperf_set_mode (XfcePanelPlugin *plugin,
 	/* Invoked when the panel changes mode */
 {
     struct monitor_t *poMonitor = &(poPlugin->oMonitor);
+    int i;
+    Widget_t       *pwBar;
     GtkOrientation    p_iOrientation;
 
-    TRACE ("diskperf_set_mode()\n");
+    DBG ("%d", p_iMode);
 
     p_iOrientation =
       (p_iMode == XFCE_PANEL_PLUGIN_MODE_HORIZONTAL) ?
       GTK_ORIENTATION_HORIZONTAL : GTK_ORIENTATION_VERTICAL;
 
+    gtk_orientable_set_orientation(GTK_ORIENTABLE(poMonitor->wBox), p_iOrientation);
 
-    if (poPlugin->iTimerId) {
-	g_source_remove (poPlugin->iTimerId);
-	poPlugin->iTimerId = 0;
+    for (i = 0; i < 2; i++) {
+	pwBar = poPlugin->oMonitor.awProgressBar + i;
+	gtk_orientable_set_orientation (GTK_ORIENTABLE(*pwBar), !p_iOrientation);
+	gtk_progress_bar_set_inverted (GTK_PROGRESS_BAR(*pwBar),
+					   (p_iOrientation ==
+					    GTK_ORIENTATION_HORIZONTAL));
     }
-    gtk_container_remove (GTK_CONTAINER (poMonitor->wEventBox),
-			  GTK_WIDGET (poMonitor->wBox));
-    CreateMonitorBars (poPlugin, p_iOrientation);
-    SetTimer (poPlugin);
     gtk_label_set_angle (GTK_LABEL (poMonitor->wTitle),
                          (p_iMode != XFCE_PANEL_PLUGIN_MODE_VERTICAL) ?
                          0 : 270);
@@ -1135,29 +1150,6 @@ static void diskperf_set_mode (XfcePanelPlugin *plugin,
 
     diskperf_set_size (plugin, xfce_panel_plugin_get_size (plugin), poPlugin);
 }				/* diskperf_set_orientation() */
-#else
-	/**************************************************************/
-
-static void diskperf_set_orientation (XfcePanelPlugin *plugin,
-                                      GtkOrientation p_iOrientation,
-                                      diskperf_t *poPlugin)
-	/* Plugin API */
-	/* Invoked when the panel changes orientation */
-{
-    struct monitor_t *poMonitor = &(poPlugin->oMonitor);
-
-    TRACE ("diskperf_set_orientation()\n");
-    if (poPlugin->iTimerId) {
-	g_source_remove (poPlugin->iTimerId);
-	poPlugin->iTimerId = 0;
-    }
-    gtk_container_remove (GTK_CONTAINER (poMonitor->wEventBox),
-			  GTK_WIDGET (poMonitor->wBox));
-    CreateMonitorBars (poPlugin, p_iOrientation);
-    SetTimer (poPlugin);
-    diskperf_set_size (plugin, xfce_panel_plugin_get_size (plugin), poPlugin);
-}				/* diskperf_set_orientation() */
-#endif
 	/**************************************************************/
 
 static void diskperf_construct (XfcePanelPlugin *plugin)
@@ -1174,14 +1166,9 @@ static void diskperf_construct (XfcePanelPlugin *plugin)
     g_signal_connect (plugin, "size-changed", G_CALLBACK (diskperf_set_size), 
                       diskperf);
 
-#ifdef HAS_PANEL_49
     g_signal_connect (plugin, "mode-changed",
                       G_CALLBACK (diskperf_set_mode), diskperf);
     xfce_panel_plugin_set_small (plugin, TRUE);
-#else
-    g_signal_connect (plugin, "orientation-changed",
-                      G_CALLBACK (diskperf_set_orientation), diskperf);
-#endif
 
     xfce_panel_plugin_menu_show_about (plugin);
     g_signal_connect (plugin, "about", G_CALLBACK (About), NULL);
